@@ -20,4 +20,6 @@ git rm --ignore-unmatch -r -f \
     assets/thirdparties/home.fredfiber.no \
     uAssets/thirdparties/mirror1.malwaredomains.com \
     uAssets/thirdparties/pgl.yoyo.org \
+    uAssets/thirdparties/winhelp2002.mvps.org \
+    uAssets/thirdparties/someonewhocares.org \
     platform/safari/vapi-background.js
